@@ -77,6 +77,8 @@ class FontFile(object):
         else:
             print("Converting to temp UFO font...")
             self.temp_ufo_path = temp_path = get_temp_dir_path('font.ufo')
+            if self.font_format == 'PFC':
+                self.ufo_format = UFOFormatVersion.FORMAT_2_0
 
             if not run_shell_command([
                     'tx', '-ufo', font_path, temp_path]):
@@ -111,7 +113,8 @@ class FontFile(object):
         else:
             if self.ufo_format <= UFOFormatVersion.FORMAT_2_0:
                 # Up-convert the UFO to format 3
-                warnings.warn("The UFO was up-converted to format 3.")
+                warnings.warn("The UFO was up-converted to format 3.",
+                              UserWarning, stacklevel=2)
                 self.ufo_format = UFOFormatVersion.FORMAT_3_0
 
                 with UFOWriter(self.defcon_font.path,
@@ -127,6 +130,12 @@ class FontFile(object):
             layer = layers[PROCD_GLYPHS_LAYER_NAME]
             glyph_set = writer.getGlyphSet(
                 layerName=PROCD_GLYPHS_LAYER_NAME, defaultLayer=False)
+            if self.font_format == "PFC":
+                libs = {}
+                for f in layers.defaultLayer._glyphs.items():
+                    libs[f[0]] = f[1].lib
+                for g in layer._glyphs.items():
+                    g[1].lib = libs[g[0]]
             writer.writeLayerContents(layers.layerOrder)
             layer.save(glyph_set)
 
@@ -249,6 +258,11 @@ def get_options(args):
         action='store_true',
         help='run in quiet mode'
     )
+    parser.add_argument(
+        '--ignore-contour-order',
+        action='store_true',
+        help='do not attempt to restore contour order'
+    )
     parser.add_argument(
         '--no-overlap-checks',
         action='store_true',
@@ -408,6 +422,7 @@ def get_options(args):
     options.check_all = parsed_args.all
     options.clear_hash_map = parsed_args.clear_hash_map
     options.write_to_default_layer = parsed_args.write_to_default_layer
+    options.ignore_contour_order = parsed_args.ignore_contour_order
 
     return options
 
@@ -871,9 +886,9 @@ def sort_contours(c1, c2):
 def restore_contour_order(fixed_glyph, original_contours):
     """ The pyClipper library first sorts all the outlines by x position,
     then y position. I try to undo that, so that un-touched contours will end
-    up in the same order as the in the original, and any conbined contours
+    up in the same order as the in the original, and any combined contours
     will end up in a similar order. The reason I try to match new contours
-    to the old is to reduce arbitraryness in the new contour order between
+    to the old is to reduce arbitrariness in the new contour order between
     similar fonts. I can't completely avoid this, but I can reduce how often
     it happens.
     """
@@ -894,7 +909,7 @@ def restore_contour_order(fixed_glyph, original_contours):
     # Match contours that have not changed.
     # This will fix the order of the contours that have not been touched.
     num_contours = len(new_list)
-    if num_contours > 0:  # If the new contours aren't already all matched..
+    if num_contours > 0:  # If the new contours aren't already all matched.
         for i in range(num_contours):
             ci, contour = new_list[i]
             for j in old_index_list:
@@ -937,20 +952,19 @@ def restore_contour_order(fixed_glyph, original_contours):
                                 if (point.x == old_start_point.x) \
                                         and (point.y == old_start_point.y) \
                                         and point.segmentType is not None:
-                                    try:
-                                        msg = ("Failed assertion: duplicated "
-                                               f"start point on contour {ci} "
-                                               f"at {point.x}, {point.y} of "
-                                               f"glyph {fixed_glyph.name}.")
-                                        assert not ctr_starts[ci], msg
-                                    except KeyError:
+                                    if ci not in ctr_starts:
                                         msg = (f"Contour index {ci} out "
                                                "of range on updated glyph "
                                                f"{fixed_glyph.name}")
                                         raise KeyError(msg)
+                                    elif ctr_starts[ci]:
+                                        msg = ("Warning: duplicated "
+                                               f"start point on contour {ci} "
+                                               f"at {point.x}, {point.y} of "
+                                               f"glyph {fixed_glyph.name}.")
+                                        print(msg)
                                     contour.setStartPoint(pi)
                                     ctr_starts[ci].append(pi)
-
                         break
                 if matched:
                     break
@@ -986,6 +1000,8 @@ def run(args=None):
     font_file = FontFile(font_path, font_format)
     use_hash_map = True if font_format == 'UFO' else False
     defcon_font = font_file.open(use_hash_map)
+    if font_format == 'PFC':
+        font_format = 'UFO'
 
     # We allow use of a hash map to skip glyphs only if fixing glyphs
     if options.clear_hash_map:
@@ -1025,9 +1041,11 @@ def run(args=None):
 
     max_length = max([len(g) for g in glyph_list])
     fmt = '{:<%d}' % max_length
-    with trange(len(glyph_list)) as t:
+    glyph_list = sorted(glyph_list)
+    list_length = len(glyph_list)
+    with trange(list_length) as t:
         for i in t:
-            glyph_name = sorted(glyph_list)[i]
+            glyph_name = glyph_list[i]
             t.set_description('Checking outlines for %s' %
                               fmt.format(glyph_name))
             changed = False
@@ -1097,12 +1115,13 @@ def run(args=None):
                 # them prior to restore_contour_order.
                 thresholdAttrGlyph(fixed_glyph, 1)
 
-                restore_contour_order(fixed_glyph, original_contours)
+                if not options.ignore_contour_order:
+                    restore_contour_order(fixed_glyph, original_contours)
 
             # The following is needed when the script is called from another
             # script with Popen():
             sys.stdout.flush()
-            if i == len(glyph_list) - 1:
+            if i == list_length - 1:
                 t.set_description("Finished checkoutlinesufo")
 
     # update layer plist: the hash check call may have deleted processed layer
