@@ -4,7 +4,7 @@
 convertfonttocid.py. v 1.13.2 Jul 30 2020
 
 Convert a Type 1 font to CID, given multiple hint dict defs in the
-"fontinfo" file. See psautohint help, with the "--doc-fddict" option,
+"fontinfo" file. See otfautohint help, with the "--doc-fddict" option,
 or the makeotf user guide for details on this format. The output file
 produced by convertFontToCID() is a CID Type 1 font, no matter what
 the input is.
@@ -508,11 +508,11 @@ def parseFontInfoFile(fontDictList, fontInfoData, glyphList, maxY, minY,
         # e.g outside of the Font BBox. We do this because if there are
         # glyphs which are not assigned to a user specified font dict,
         # it is because it doesn't make sense to provide alignment zones
-        # for the glyph. Since psautohint does require at least one bottom zone
-        # and one top zone, we add one bottom and one top zone that are
+        # for the glyph. Since otfautohint does require at least one bottom
+        # zone # and one top zone, we add one bottom and one top zone that are
         # outside the font BBox, so that hinting won't be affected by them.
         # NOTE: The FDDict receives a special name "No Alignment Zones" which
-        # psautohint recognizes.
+        # otfautohint recognizes.
         defaultFDDict = fontDictList[0]
 
         for key in kBlueValueKeys + kOtherBlueValueKeys:
